@@ -132,6 +132,7 @@ type styles struct {
 type Model struct {
 	revision     *jj.Commit
 	files        list.Model
+	mode         mode
 	height       int
 	confirmation *confirmation.Model
 	context      *context.MainContext
@@ -144,12 +145,11 @@ func (m Model) ShortHelp() []key.Binding {
 		return m.confirmation.ShortHelp()
 	}
 	return []key.Binding{
-		m.keyMap.Up,
-		m.keyMap.Down,
 		m.keyMap.Cancel,
 		m.keyMap.Details.Diff,
 		m.keyMap.Details.ToggleSelect,
 		m.keyMap.Details.Split,
+		m.keyMap.Details.Squash,
 		m.keyMap.Details.Restore,
 		m.keyMap.Details.Absorb,
 		m.keyMap.Details.RevisionsChangingFile,
@@ -191,6 +191,7 @@ func New(context *context.MainContext, revision *jj.Commit) Model {
 	return Model{
 		revision: revision,
 		files:    l,
+		mode:     viewMode,
 		context:  context,
 		keyMap:   keyMap,
 		styles:   s,
@@ -241,6 +242,9 @@ func (m Model) Update(msg tea.Msg) (Model, tea.Cmd) {
 			)
 			m.confirmation = model
 			return m, m.confirmation.Init()
+		case key.Matches(msg, m.keyMap.Details.Squash):
+			m.mode = squashTargetMode
+			return m, common.JumpToParent(m.revision)
 		case key.Matches(msg, m.keyMap.Details.Restore):
 			selectedFiles, isVirtuallySelected := m.getSelectedFiles()
 			m.files.SetDelegate(itemDelegate{
@@ -310,7 +314,7 @@ func (m Model) Update(msg tea.Msg) (Model, tea.Cmd) {
 			return m, nil
 		case key.Matches(msg, m.keyMap.Details.RevisionsChangingFile):
 			if item, ok := m.files.SelectedItem().(item); ok {
-				return m, tea.Batch(common.Close, common.UpdateRevSet(fmt.Sprintf("files(\"%s\")", item.fileName)))
+				return m, tea.Batch(common.Close, common.UpdateRevSet(fmt.Sprintf("files(%s)", jj.EscapeFileName(item.fileName))))
 			}
 		default:
 			if len(m.files.Items()) > 0 {
