@@ -2,9 +2,10 @@ package ui
 
 import (
 	"fmt"
-	"github.com/charmbracelet/bubbles/help"
 	"time"
 
+	"github.com/charmbracelet/bubbles/help"
+
 	"github.com/idursun/jjui/internal/ui/flash"
 
 	"github.com/charmbracelet/bubbles/key"
@@ -57,10 +58,6 @@ func (m Model) Init() tea.Cmd {
 }
 
 func (m Model) handleFocusInputMessage(msg tea.Msg) (tea.Model, tea.Cmd, bool) {
-	if x, ok := msg.(leader.PendingMsg); ok {
-		return m, leader.TakePending(x), true
-	}
-
 	// capture all keys while on aceJump mode.
 	if k, ok := msg.(tea.KeyMsg); ok && m.revisions.IsAceJumping() {
 		return m, m.revisions.HandleAceJump(k), true
@@ -190,6 +187,10 @@ func (m Model) Update(msg tea.Msg) (tea.Model, tea.Cmd) {
 			cmds = append(cmds, leader.InitCmd)
 		case key.Matches(msg, m.keyMap.FileSearch.Toggle):
 			rev := m.revisions.SelectedRevision()
+			if rev == nil {
+				// noop if current revset does not exist (#264)
+				return m, nil
+			}
 			out, _ := m.context.RunCommandImmediate(jj.FilesInRevision(rev))
 			return m, common.FileSearch(m.revsetModel.Value, m.previewVisible, rev, out)
 		case key.Matches(msg, m.keyMap.QuickSearch) && m.oplog != nil:
